import random
from zope.interface import implements
from zope.app.component.hooks import getSite 
from elektrika.openx.interfaces import IOpenXJSInvocation
import logging
logger = logging.getLogger('elektrika.openx')


class OpenXJSInvocation(object):
    implements(IOpenXJSInvocation)

    def code(self, zone, withtext=0, target='_blank'):
        try:
            zone = int(zone)
        except ValueError:
            return ''
            
        # try to get ad server name
        site = getSite()
        server = site.getProperty('openx_server', '')
        
        if not server:
            logger.error("No OpenX server defined. Please set server URL in plone site property 'openx_server'. Do not include http:// in the server name!")
            return ''
            
        text = """
        <script type="text/javascript"><!--//<![CDATA[
           var m3_u = (location.protocol=='https:'?'https://%(server)s/www/delivery/ajs.php':'http://%(server)s/www/delivery/ajs.php');
           var m3_r = Math.floor(Math.random()*99999999999);
           if (!document.MAX_used) document.MAX_used = ',';
           document.write ("<scr"+"ipt type='text/javascript' src='"+m3_u);
        """ % {'server': server}
        subtext = 'document.write ("?zoneid=%s' % zone
        if withtext:
            subtext = subtext + '&amp;withtext=1'
        if target:
            subtext = subtext + '&amp;target=%s' % target
        subtext = subtext + '");' 
        text = text + subtext
        text = text + """  
           document.write ('&amp;cb=' + m3_r);
           if (document.MAX_used != ',') document.write ("&amp;exclude=" + document.MAX_used);
           document.write (document.charset ? '&amp;charset='+document.charset : (document.characterSet ? '&amp;charset='+document.characterSet : ''));
           document.write ("&amp;loc=" + escape(window.location));
           if (document.referrer) document.write ("&amp;referer=" + escape(document.referrer));
           if (document.context) document.write ("&context=" + escape(document.context));
           if (document.mmm_fo) document.write ("&amp;mmm_fo=1");
           document.write ("'><\/scr"+"ipt>");
        //]]>--></script>
        """
        rnd = random.randint(10000,99999)
        text = text + """<noscript><a href="http://%s/www/delivery/ck.php?n=acbe940d&amp;cb==%d" target="_blank"><img src="http://%s/www/delivery/avw.php?zoneid=%s&amp;cb=%d&amp;n=acbe940d" border="0" alt="" /></a></noscript>""" % (server, rnd, server, zone, rnd)

        return text        
        


from zope.interface import implements
from zope.component import getUtility
from Acquisition import aq_inner
from Products.Five import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.memoize import view

from elektrika.openx.interfaces import IOpenXJSInvocation

class OpenXView(BrowserView):
    """ This view may be used from any template 

        <div tal:define="openx context/openx_view"
             tal:replace="structure python:openx.code(38)" />

    """
    def code(self, zone, withText=False, target='_blank'):
        util = getUtility(IOpenXJSInvocation)
        return util.code(zone, withText, target)



from zope.interface import implements
from zope.component import getMultiAdapter, getUtility
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.layout.viewlets.common import ViewletBase
from plone.memoize import view

from elektrika.openx.interfaces import IOpenXJSInvocation
from elektrika.openx import eOpenXMessageFactory as _ 

class OpenXBannerViewlet(ViewletBase):

    def code(self, zone, withText=False, target='_blank'):
        util = getUtility(IOpenXJSInvocation)
        return util.code(zone, withText, target)
    
    




import random 
from zope import schema 
from zope.component import getMultiAdapter, getUtility
from zope.formlib import form 
from zope.interface import implements 
from plone.app.portlets.portlets import base 
from plone.memoize.instance import memoize 
from plone.portlets.interfaces import IPortletDataProvider 
from DateTime import DateTime 
from Acquisition import aq_inner 
from Products.CMFCore.interfaces import ICatalogTool 
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile 
from Products.CMFCore.utils import getToolByName 

from elektrika.openx.interfaces import IOpenXJSInvocation
from elektrika.openx import eOpenXMessageFactory as _ 

class IOpenXPortlet(IPortletDataProvider): 
    zone = schema.Int(title=_(u'Zone number'), 
                      description=_(u'Enter zone number'), 
                      required=True) 
                       
    showBorder = schema.Bool(title=_(u"Show portlet border?"), 
                           description=u"", 
                           required=False,
                           default=False) 

    withText = schema.Bool(title=_(u"Append text to the banner?"), 
                           description=_(u"If enabled, there will be text of banner appended to the banner image"), 
                           required=False,
                           default=False) 
                           
    target = schema.TextLine(title=_(u"Target frame"), 
                             description=_(u"_blank, _new, nothing, frame name, ..."), 
                             required=False,
                             default=u'_blank') 

    cssClass = schema.TextLine(title=_(u"CSS class"), 
                             description=_(u"Enter css class for portlet. More than one class may be separated by space. Default is 'portlet portletOpenX'"), 
                             required=True,
                             default=u'portlet portletOpenX') 

    cssId = schema.TextLine(title=_(u"CSS ID"), 
                             description=_(u"Enter CSS ID for this portlet. This text must be unique around the page. Default is blank."), 
                             required=False,
                             default=u'') 

class Assignment(base.Assignment): 
    implements(IOpenXPortlet) 
    def __init__(self, zone=None, showBorder=False, withText=False, target=u'_blank', cssClass=None, cssId=None): 
        self.zone = zone 
        self.showBorder = showBorder
        self.withText = withText 
        self.target = target
        self.cssClass = cssClass
        self.cssId = cssId
         
    @property 
    def title(self): 
        return _(u"OpenX banner") 

class Renderer(base.Renderer): 
    render = ViewPageTemplateFile('openx_portlet.pt') 
    
    @property 
    def available(self): 
        return True
        
    @property
    def cssId(self):
        if self.data.cssId:
            return self.data.cssId
        else:
            return None

    @property
    def cssClass(self):
        return self.data.cssClass

    @property
    def showBorder(self):
        return self.data.showBorder
        
    def code(self): 
        util = getUtility(IOpenXJSInvocation)
        return util.code(self.data.zone, self.data.withText, self.data.target)
                       
class AddForm(base.AddForm): 
    form_fields = form.Fields(IOpenXPortlet) 
    label = _(u"Add OpenX portlet") 
    description = _(u"This portlet displays ad banners") 
    
    def create(self, data): 
        assignment = Assignment() 
        form.applyChanges(assignment, self.form_fields, data) 
        return assignment 
        
class EditForm(base.EditForm): 
    form_fields = form.Fields(IOpenXPortlet) 
    label = _(u"Edit OpenX portlet") 
    description = _(u"This portlet displays ad banners.") 

